/*
 * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite. If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */



package com.openexchange.office.datasource.impl;

import java.io.InputStream;
import java.util.Optional;
import java.util.concurrent.atomic.AtomicReference;
import com.openexchange.office.datasource.access.DataSourceAccess;
import com.openexchange.office.datasource.access.DataSourceException;
import com.openexchange.office.datasource.access.DataSourceResourceAccess;
import com.openexchange.office.datasource.access.MetaData;

public class DataSourceResourceAccessImpl implements DataSourceResourceAccess {

	private final DataSourceAccess dataSourceAccess;
	private final String folderId;
	private final String id;
	private final String versionOrAttachmentId;
	private final Optional<String> authCode;
	private AtomicReference<MetaData> cachedMetaData = new AtomicReference<>();

	public DataSourceResourceAccessImpl(DataSourceAccess dataSourceAccess, String folderId, String id, String versionOrAttachmentId, Optional<String> authCode) {
		this.dataSourceAccess = dataSourceAccess;
		this.folderId = folderId;
		this.id = id;
		this.versionOrAttachmentId = versionOrAttachmentId;
		this.authCode = authCode;
	}

	@Override
	public String getFolder() {
		return folderId;
	}

	@Override
	public String getId() {
		return id;
	}

	@Override
	public String getVersionOrAttachmentId() {
		return versionOrAttachmentId;
	}

	@Override
	public Optional<String> getAuthCode() {
		return authCode;
	}

	@Override
	public int getContextId() {
		return dataSourceAccess.getContextId();
	}

	@Override
	public boolean canRead() throws DataSourceException {
		return dataSourceAccess.canRead(folderId, id, versionOrAttachmentId);
	}

	@Override
	public MetaData getMetaData() throws DataSourceException {
		MetaData metaData = cachedMetaData.get();

		// use meta data cache for all data sources except drive where the content can
		// change
		if (null == metaData) {
			metaData = dataSourceAccess.getMetaData(folderId, id, versionOrAttachmentId, authCode);
			if (!(dataSourceAccess instanceof DataSourceAccessDrive)) {
				cachedMetaData.compareAndSet(null, metaData);
			}
		}

		return metaData;
	}

	@Override
	public InputStream getContentStream() throws DataSourceException {
		return dataSourceAccess.getContentStream(folderId, id, versionOrAttachmentId, authCode);
	}

}
